==> openGion_dev_5.0.2.0.zip: opengion/uap/webapps/gf/src/org/opengion/fukurou/taglet/TagletRev.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.taglet;

import com.sun.tools.doclets.Taglet;
import com.sun.javadoc.Tag;
import java.util.Map;
import org.opengion.fukurou.util.StringUtil;

/**
 * ソースコメントから、Javadoc を作成する場合のカスタムタグ情報を作成する
 * Taglet インターフェースの実装クラスを作成します。
 * og.rev タグ(変更履歴)を処理します。
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class TagletRev extends AbstractTaglet {

	private static final String NAME = "og.rev";
	private static final String HEADER = "変更履歴:";

	/**
	 * 実行時にドックレットがタグレットを読み込んで使用するには、
	 * そのタグレットが、次のシグニチャでマップ を引数として受け取る、
	 * レジスタ と呼ばれる static メソッドをもっている必要があります。
	 * このメソッドは、タグレット名をキーとして、カスタムタグレットの
	 * インスタンスをマップに追加します。 タグレットをオーバーライドする場合、
	 * 名前の競合を避けるため、新しいタグレットのインスタンスをマップに
	 * 追加する前に、オーバーライドされる側のタグレットをマップから
	 * 削除する必要があります。
	 *
	 * @param tagletMap Map
	 */
	public static void register( final Map<String,Taglet> tagletMap ) {
	   TagletRev tagRev = new TagletRev();
	   Taglet tag = tagletMap.get(NAME);
	   if(tag != null) {
		   tagletMap.remove(NAME);
	   }
	   tagletMap.put(NAME, tagRev);
	}

	/**
	 * このカスタムタグの名前を返します。
	 *
	 * @return カスタムタグの名前
	 */
	public String getName() {
		return NAME;
	}

	/**
	 * このカスタムタグのタグ表現を受け取り、
	 * 文字列としての表現を返し、生成されたページに出力します。
	 *
	 * @param tagTag このカスタムタグのタグ表現
	 * @return このタグの文字列としての表現
	 */
	public String toString( final Tag tagTag ) {
		return "<li />"
			   + StringUtil.htmlFilter( tagTag.text() ) ;
	}

	/**
	 * このカスタムタグのタグ表現の配列を受け取り、
	 * 文字列としての表現を返し、生成されたページに出力します。
	 * このタグレットがインラインタグを表す場合、
	 * このメソッドは null を返します。
	 *
	 * @param tagTags Tag[] このカスタムタグを表すタグの配列
	 * @return このタグの文字列としての表現
	 */
	public String toString( final Tag[] tagTags ) {
		if(tagTags.length == 0) {
			return null;
		}
		StringBuilder result = new StringBuilder();
		result.append( "<dt><b>" + HEADER + "</b><dd>" );
		result.append( "<table cellpadding=2 cellspacing=0>" );
		for(int i = 0; i < tagTags.length; i++) {
			result.append( "<tr><td>" );
			result.append( tagTags[i].text() );
			result.append( "</td></tr>" );
		}
		result.append( "</table></dd>\n" );
		return result.toString();
	}
}

==> openGion_dev_5.5.0.0.zip: opengion/uap/webapps/gf/src/org/opengion/fukurou/taglet/TagletRev.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.taglet;

import com.sun.tools.doclets.Taglet;
import com.sun.javadoc.Tag;
import java.util.Map;
import org.opengion.fukurou.util.StringUtil;

/**
 * ソースコメントから、Javadoc を作成する場合のカスタムタグ情報を作成する
 * Taglet インターフェースの実装クラスを作成します。
 * og.rev タグ(変更履歴)を処理します。
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class TagletRev extends AbstractTaglet {

	private static final String NAME   = "og.rev";
	private static final String HEADER = "変更履歴:";

	/**
	 * 実行時にドックレットがタグレットを読み込んで使用するには、
	 * そのタグレットが、次のシグニチャでマップ を引数として受け取る、
	 * レジスタ と呼ばれる static メソッドをもっている必要があります。
	 * このメソッドは、タグレット名をキーとして、カスタムタグレットの
	 * インスタンスをマップに追加します。 タグレットをオーバーライドする場合、
	 * 名前の競合を避けるため、新しいタグレットのインスタンスをマップに
	 * 追加する前に、オーバーライドされる側のタグレットをマップから
	 * 削除する必要があります。
	 *
	 * @param tagletMap Map
	 */
	public static void register( final Map<String,Taglet> tagletMap ) {
	   TagletRev tagRev = new TagletRev();
	   Taglet tag = tagletMap.get(NAME);
	   if(tag != null) {
		   tagletMap.remove(NAME);
	   }
	   tagletMap.put(NAME, tagRev);
	}

	/**
	 * このカスタムタグの名前を返します。
	 *
	 * @return カスタムタグの名前
	 */
	public String getName() {
		return NAME;
	}

	/**
	 * このカスタムタグのタグ表現を受け取り、
	 * 文字列としての表現を返し、生成されたページに出力します。
	 *
	 * @param tagTag このカスタムタグのタグ表現
	 * @return このタグの文字列としての表現
	 */
	public String toString( final Tag tagTag ) {
		return "<li />"
			   + StringUtil.htmlFilter( tagTag.text() ) ;
	}

	/**
	 * このカスタムタグのタグ表現の配列を受け取り、
	 * 文字列としての表現を返し、生成されたページに出力します。
	 * このタグレットがインラインタグを表す場合、
	 * このメソッドは null を返します。
	 *
	 * @og.rev 5.1.9.0 (2010/08/01) dtタグをきちんと記述する。
	 *
	 * @param tagTags Tag[] このカスタムタグを表すタグの配列
	 * @return このタグの文字列としての表現
	 */
	public String toString( final Tag[] tagTags ) {
		if(tagTags.length == 0) {
			return null;
		}
		StringBuilder result = new StringBuilder();
		result.append( "<dt><b>" ).append( HEADER ).append( "</b></dt>" );		// 5.1.9.0 (2010/08/01)
		result.append( "<dd><table cellpadding=\"2\" cellspacing=\"0\">" );
		for(int i = 0; i < tagTags.length; i++) {
			result.append( "<tr><td>" );
			result.append( link( tagTags[i].text() ) );
			result.append( "</td></tr>" );
		}
		result.append( "</table></dd>\n" );
		return result.toString();
	}
}
